function    [rad,a,c] = grid_RAD_CSIDE(dat,PASS,Ai,Ci,alims,da,dc);
%
% USAGE:    [rad,a,c] = grid_RAD_CSIDE(dat,PASS,Ai,Ci,alims,da,dc);
%
% dat = matlab I/O file structure with field "rad" a function of (X,Y,wavelength)
% pass is the pass number in the event of an error. 

% first generate queiry grid at 2m resolution
if ~exist('da','var')
da= 10;
dc= 2;
end
a = alims(1):da:alims(2);
c =[alims(3):dc:alims(4)]';
[aa,cc] = meshgrid(a,c);
%
% size of input array
[nc,na] = size(aa);
%
% number of bands
Nb = 126;
%
% determine which indices to load
[iAC,jAC] = find(Ai>=alims(1)-10 & Ai<=alims(2)+10 &...
                 Ci>=alims(3)-10 & Ci<=alims(4)+10);
%
if isempty(iAC)
disp(['no data in (a,c) grid: PASS: ', num2str(PASS)])
rad = []
% a   = A;
% c   = C';
return
end
%
% start row (i) is first instance of (iA,iC) etc.
iS = min(iAC);
iE = max(iAC);
jS = min(jAC);
jE = max(jAC);
%
%
% number of sample points
ni = 1+(iE-iS);
nj = 1+(jE-jS);
ns = ni*nj;
%
%
rad = nan(nc,na,Nb);
%
% max variable size
maxsize = 250e6;
nb = floor(maxsize/(ns));
%
maxi = floor(Nb/nb);
AAi = Ai(iS:iE,jS:jE);
CCi = Ci(iS:iE,jS:jE);
%
%
disp('prepping data mask')
% bnd   = boundary(AAi(:),CCi(:),0.1);
% in    = inpolygon(aa,cc,AAi(bnd),CCi(bnd));
dumA = AAi(1:100:end)';
dumC = CCi(1:100:end)';
bnd   = boundary(dumA,dumC,0.75);
in    = inpolygon(aa,cc,dumA(bnd),dumC(bnd));
i0 = find(in);
% 
[rmask,cmask] = ind2sub(size(aa),i0);
nm = length(rmask);
% mask0(in) = 1;
disp('extracting bands...')
%
if maxi>=1
    for i = 1:maxi
        ii = 1 + [[0:nb-1] + nb*(i-1)];
        dum = reshape(dat.RAD(iS:iE,jS:jE,ii),ni*nj,nb);
        F = scatteredInterpolant(AAi(:),CCi(:),dum(:,1),'linear','none');
        disp(['gridding iter: ',num2str(i),' of: ',num2str(maxi)])
        for jj = 1:nb
            F.Values = dum(:,jj);
            dum2 = F(aa(i0),cc(i0));
            i1 = sub2ind(size(rad),rmask,cmask,ones(nm,1)*ii(jj));
            rad(i1) = dum2;
            % rad(:,:,ii(jj)) = reshape(dum2,nc,na,1);
        end
    end
    if maxi*nb<Nb
        ii = ii(end)+1:Nb;
        nb = length(ii);
        dum = reshape(dat.RAD(iS:iE,jS:jE,ii),ni*nj,nb);
        disp(['gridding last iter...'])
        for jj = 1:nb
            F.Values = dum(:,jj);
            dum2 = F(aa(i0),cc(i0));
            i1 = sub2ind(size(rad),rmask,cmask,ones(nm,1)*ii(jj));
            rad(i1) = dum2;
            % rad(:,:,ii(jj)) = reshape(dum2,nc,na,1);
        end
    end
else
        dum = reshape(dat.RAD(iS:iE,jS:jE,1:Nb),ni*nj,Nb);
        % initialize interpolant
        F = scatteredInterpolant(AAi(:),CCi(:),dum(:,1),'linear','none');
        for ii = 1:Nb
            F.Values = dum(:,ii);
            dum2 = F(aa(i0),cc(i0));
            i1 = sub2ind(size(rad),rmask,cmask,ones(nm,1)*ii);
            rad(i1) = dum2;
            % rad(:,:,ii) = reshape(dum2,nc,na,1);
        end
end
%
disp('done!')




