function [Dsz,Dis] = solve_SZ_IS_dye_adv_diff_v2(y,dt,Vsz, Vis, iQ, Q, kdecay, k_inactivation, Kyy, Asz_Ais, ISkdecay,KyyIS)
%
% USAGE: [Dsz,Dis] = solve_SZ_IS_dye_adv_diff_v2(y,dt,Vsz, Vis, iQ, Q, kdecay, k_inactivation, Kyy, Asz_Ais,ISkdcay,KyyIS)
%
% Vsz should have length()=nt, with nt=(number of time-steps); and dt<min(Vsz/dy) is a constant time-step
% kdecay (1/s) is tracer decay rate, kdecay ~ u_ex/Lsz ...
% Asz_Ais is conversion factor Lsz/[Lis*(1+Lis^2/Lsz/2)] for kdecay, Dis uses kdecay*Asz_Ais
% Q is source concentration time-series, for initial condition make Q(nIQ,1)=Q0(1:nIQ) and Q(:,2:end)=0;
% iQ are indices over which Q is distributed, be sure that iQ(1)>=3 and iQ(end)<=nt-2. 
% kyy is Fickian surf-zone shear disp; kyyIS if for inner-shelf region

%keyboard
ny = length(y);
nt = length(Vsz);
dy = y(2)-y(1);
Dsz = zeros(ny,nt);
Dis = zeros(ny,nt);
%
% get intial condition shape 
nIQ = length(iQ);
[nQ,nQt] = size(Q);
if     nQ==nIQ & nQt==nt, disp('using release Q(y,t)');
elseif nQ~=nIQ & nQt==nt, Q=ones(nIQ,1)*Q; disp('using release ones(nIQ,1)*Q')
elseif nQ==1   & nQt==1 , Q=ones(nIQ,nt)*Q;disp('using release Q*ones(iQ,nt)')
else, disp('issue: size(Q) ~= [nIQ , nt]'), return, end
%
% initialize shoreline dye profile
Dsz(iQ,1) = Q(:,1);
%
%
% figure, plot(y,Dsz(:,1),'-k','linewidth',2), hold on
% xlabel('$y~\mathrm{m}$', 'interpreter','latex'),
% ylabel('$D~\mathrm{ppb}$', 'interpreter','latex')
%
% indices for diferences
% iC2=[3:ny-2]';
iC = [2:ny-1]';
%
% choose a scheme...
% iC = iC2;
% 2nd order weights for center second-differences
wC = [1; -2; 1];% central
% wF =-[3; -4; 1]/2;% forward for boundary points
% wB =-flipud(wF);% backward for boundary points
%
% 2nd order weights for upwind first-difference
wP2 =-[3; -4; 1]/2;% negative Vsz (P=i+)
wM2 =-flipud(wP2); % positive Vsz (P=i-)
% 1st order weights for upwind first-difference
wM  = [-1; 1];
wP  =-flipud(wM);
%
w2M = 1/2*[-1; 1];
w2P = 1/2*[-1; 1];
% 
ord0 = 1;
for i=2:nt,
%    if rem(10*i,10^floor(log10(nt)))==0,
    if rem(10*i,nt)==0,
        disp(sprintf('doing i=%d of nt=%d',i,nt));
    end;

    % sign & magnitude of alongshore velocity
    ap = max(Vsz(i-1),0); 
    am = min(Vsz(i-1),0);
    % u(n+1) = u(n) + dt*(a+*u- + a-*u+);
    UW = am*( [Dsz(iC  ,i-1), Dsz(iC+1,i-1)]*wP  )/(dy)+...
         ap*( [Dsz(iC-1,i-1), Dsz(iC  ,i-1)]*wM  )/(dy);
    % slope correction to u-wind scheme
    sig1 = minmod(  [Dsz(iC  ,i-1), Dsz(iC+1,i-1)]*wP/dy, 2*[Dsz(iC-1,i-1), Dsz(iC  ,i-1)]*wM/dy);
    sig2 = minmod(2*[Dsz(iC  ,i-1), Dsz(iC+1,i-1)]*wP/dy,   [Dsz(iC-1,i-1), Dsz(iC  ,i-1)]*wM/dy);
    % pad boundaries...
    sig1 = [sig1(1); sig1; sig1(end)];
    sig2 = [sig2(1); sig2; sig2(end)];
    sig = maxmod(sig1,sig2);
    UWcor = (0.5/dy)*( am*( sig(iC+1) - sig(iC) ) + ap*( sig(iC) - sig(iC-1) ) ).*(dy-ap*dt+am*dt);
    %
    % d^2/dy^2 (D) to 2nd order 
    Dyy = [Dsz(iC-1,i-1) Dsz(iC,i-1) Dsz(iC+1,i-1)]*wC/(dy)^2;
    %
    RHS = - UW - UWcor - (kdecay)*(Dsz(iC,i-1)-Dis(iC,i-1)) -  k_inactivation*Dsz(iC,i-1) + Kyy*Dyy;
    % add source 
    RHS(iQ-iC(1)+1) = RHS(iQ-iC(1)+1) + Q(:,i);
    % RHS(iQTJ) = RHS(iQTJ) + QTJ(i);
    
    Dsz(iC,i) = Dsz(iC,i-1) + dt*RHS;

    ap = max(Vis(i-1),0); 
    am = min(Vis(i-1),0);
    % u(n+1) = u(n) + dt*(a+*u- + a-*u+);
    UW = am*( [Dis(iC  ,i-1), Dis(iC+1,i-1)]*wP  )/(dy)+...
         ap*( [Dis(iC-1,i-1), Dis(iC  ,i-1)]*wM  )/(dy);
    %
    % slope correction
    sig1 = minmod(  [Dis(iC  ,i-1), Dis(iC+1,i-1)]*wP/dy, 2*[Dis(iC-1,i-1), Dis(iC  ,i-1)]*wM/dy);
    sig2 = minmod(2*[Dis(iC  ,i-1), Dis(iC+1,i-1)]*wP/dy,   [Dis(iC-1,i-1), Dis(iC  ,i-1)]*wM/dy);
    sig1 = [sig1(1); sig1; sig1(end)];
    sig2 = [sig2(1); sig2; sig2(end)];
    sig = maxmod(sig1,sig2);
    UWcor = (0.5/dy)*( am*( sig(iC+1) - sig(iC) ) + ap*( sig(iC) - sig(iC-1) ) ).*(dy-ap*dt+am*dt);
    %
    Dyy = [Dis(iC-1,i-1) Dis(iC,i-1) Dis(iC+1,i-1)]*wC/(dy)^2;

    RHS = - UW - UWcor - ISkdecay*Dis(iC,i-1) - (Asz_Ais*kdecay)*(Dis(iC,i-1)-Dsz(iC,i-1)) - k_inactivation*Dis(iC,i-1) + KyyIS*Dyy;

    Dis(iC,i) = Dis(iC,i-1) + dt*RHS;    

end;

% Dsz = Dsz(iC,:);
% ys =  y(iC);    
    
